@@ -30,13 +30,6 @@
 
 namespace KScreen {
 
-OsdManager* OsdManager::s_instance = nullptr;
-
-OsdAction::OsdAction(QObject *parent)
-    : QObject(parent)
-{
-}
-
 class OsdActionImpl : public OsdAction
 {
     Q_OBJECT
@@ -58,7 +51,9 @@ OsdManager::OsdManager(QObject *parent)
     : QObject(parent)
     , m_cleanupTimer(new QTimer(this))
 {
-    qmlRegisterUncreatableType<OsdAction>("org.kde.KScreen", 1, 0, "OsdAction", "You cannot create OsdAction");
+    qmlRegisterSingletonType<KScreen::OsdAction>("org.kde.KScreen", 1, 0, "OsdAction", [](QQmlEngine *, QJSEngine *) -> QObject* {
+        return new KScreen::OsdAction();
+    });
 
     // free up memory when the osd hasn't been used for more than 1 minute
     m_cleanupTimer->setInterval(60000);
@@ -82,14 +77,6 @@ OsdManager::~OsdManager()
 {
 }
 
-OsdManager* OsdManager::self()
-{
-    if (!OsdManager::s_instance) {
-        s_instance = new OsdManager();
-    }
-    return s_instance;
-}
-
 void OsdManager::showOutputIdentifiers()
 {
     connect(new KScreen::GetConfigOperation(), &KScreen::GetConfigOperation::finished,
@@ -120,8 +107,8 @@ void OsdManager::slotIdentifyOutputs(KScreen::ConfigOperation *op)
 
 void OsdManager::showOsd(const QString& icon, const QString& text)
 {
-    qDeleteAll(m_osds);
-    m_osds.clear();
+    hideOsd();
+
     connect(new KScreen::GetConfigOperation(), &KScreen::GetConfigOperation::finished,
         this, [this, icon, text] (KScreen::ConfigOperation *op) {
             if (op->hasError()) {
